---
name: Solver
about: Suggest a solver to implement
title: "[SOLVER]"
labels: solver
assignees: Jamesflynn1

---
**Provide the solver name**

**Link a paper or provide a reference for the described solver**
A link to a paper describing the solver or an academic reference. If this isn't suitable please provide a detailed description of the algorithm.

**Describe a usecase of the solver**
An example of a usecase where current solvers are insufficent (e.g. slow, incorrect, too complex)
 or the solver could be improved (e.g. additional functionality).
 
**Describe alternatives you've considered (optional)**
If A clear and concise description of any alternative solutions or features you've considered.

**Describe changes to pyRBM core code that might be required to implement (optional)**
Provide a list of changes and/or external libraries that will be required to implement the solver

**Additional context (optional)**
Add any other context or screenshots about the solver request here.
